//
//  AppDelegate.swift
//  PresenceSDK-DemoIntegration
//
//  Created by Varun Bansal on 2/9/18.
//  Copyright © 2018 Ticketmaster. All rights reserved.
//

import Foundation
import UIKit
import PresenceSDK // for PSDK.shared

@UIApplicationMain
class AppDelegate: UIResponder, UIApplicationDelegate {

    var window: UIWindow?

    func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?) -> Bool {
        // this doesn't need to be in the AppDelegate/SceneDelegate, it just needs to be called before trying to use the Presence SDK
        configurePresenceSDK()
        return true
    }
    
    // TODO: your actual Consumer Key can be found on the Ticketmaster Dev Portal: https://developer.ticketmaster.com
    static var consumerKey: String  = "<yourConsumerKey>"   // required, ex: "FcVGWRhjkzhuhEPZGbVOtQ7RL8I36Wgk" <- not real
    static var teamName: String?                            // optional, ex: "Milwaukee Bucks"
    static var hostEnvironment: PSDK.HostEnvironment = .US  // optional, if you are using the UK Host, please set this to .UK
    
    // use different colors for various UI elements:
    //static var appBrandingColors: BrandingColors = BrandingColors(navBarColor: navColor, ticketColor: ticketColor, buttonColor: buttonColor)
    
    // or use same color for all three options:
    static var appBrandingColors: PSDK.BrandingColors = PSDK.BrandingColors(oneColor: brandingColor)

    static let brandingColor = UIColor(red: 0.1960784346, green: 0.3411764801, blue: 0.1019607857, alpha: 1.0) // Bucks team brand color
}

fileprivate extension AppDelegate {

    /// configure the Presence SDK, required
    func configurePresenceSDK() {
        guard AppDelegate.consumerKey != "<yourConsumerKey>" else {
            fatalError("Make sure to enter your own Consumer/API Key into the AppDelegate.consumerKey")
        }
        
        // 1a. Configure Presence SDK
        // This can be called in AppDelegate or anywhere else as long as it is called before trying to display tickets
        PSDK.shared.setConfig(consumerKey: AppDelegate.consumerKey,
                              hostEnvironment: AppDelegate.hostEnvironment,
                              displayName: AppDelegate.teamName,
                              autoLogin: false) // do not automatically prompt login
        
        // 2. Configure your branding color for the SDK:
        PSDK.shared.setBrandingColors(AppDelegate.appBrandingColors)
        
        // 3. Configure theme for the SDK
        PSDK.shared.setTheme(theme: .Light)
        
        PSDK.shared.checkConfig {
            // API Key is good, PSDK is configured
            print("Configuration is Valid")
            self.addPresenceSDKDelegateClass()
            
        } failure: { error in
            // something went wrong:
            // 1. API is invalid
            // 2. PresenceSDK could not connect to servers
            print("Configuration Invalid: \(error?.localizedDescription ?? "<nil>")")
        }
    }
    
    /// configure a class to listen to the PresenceSDK, optional
    func addPresenceSDKDelegateClass() {
        // simply assigning this manager also creates it
        _ = PresenceManager.shared
    }
}
