//
//  ChooseModeViewController.swift
//  PresenceSDKDemoIntegration
//
//  Created by Jonathan Backer on 10/11/21.
//  Copyright © 2021 Ticketmaster. All rights reserved.
//

import UIKit
import PresenceSDK // for PresenceViewController

class ChooseModeViewController: UITableViewController {
    
    override var preferredStatusBarStyle: UIStatusBarStyle {
        return .lightContent
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
                
        title = "Presence SDK v\(PSDK.shared.version)"
        
        // make the demo integration app header color match the branding color
        // iOS 13+ navigationBar color
        let barAppearance = UINavigationBarAppearance()
        barAppearance.backgroundColor = AppDelegate.brandingColor
        barAppearance.titleTextAttributes = [NSAttributedString.Key.foregroundColor: UIColor.white]
        navigationController?.navigationBar.standardAppearance = barAppearance
        navigationController?.navigationBar.scrollEdgeAppearance = barAppearance
    }

    override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        if indexPath.section == 0 && indexPath.row == 0 {
            // launch Presence SDK via push
            let presenceViewController = PresenceViewController()
            
            // set navBar title (optional):
            //presenceViewController.title = "My Team Events"
            
            navigationController?.pushViewController(presenceViewController, animated: true)
            
        } else if indexPath.section == 0 && indexPath.row == 1 {
            // launch PresenceSDK via modal
            let presenceViewController = PresenceViewController()
            
            // set navBar title (optional):
            //presenceViewController.title = "My Team Events"
            
            // set modal presentation style (optional):
            presenceViewController.modalPresentationStyle = .fullScreen
            
            present(presenceViewController, animated: true, completion: nil)
            
        } else if indexPath.section == 0 && indexPath.row == 5 {
            // logout of PresenceSDK (all accounts)
            PSDK.shared.logOut(forceLogout: false) { hostSuccess, hostError, teamSuccess, teamError, sportXRSuccess, sportXRError in
                // all done
                print("Logout completed")
            }
            
        } else {
            // the Main.storyboard segues handle all other rows
        }
    }
}
