//
//  PresenceManager+OrderDelegate.swift
//  PresenceSDKDemoIntegration
//
//  Created by Jonathan Backer on 10/11/21.
//  Copyright © 2021 Ticketmaster. All rights reserved.
//

import Foundation
import PresenceSDK // for PresenceOrderDelegate

extension PresenceManager: PresenceOrderDelegate {
    
    // all methods are optional
    
    /// Method is invoked if the core app need to display artist detail page..
    /// - parameter artistId: Identidier of the artist to be launched in ADP.
    func presentArtistDetailsPage(with artistId: String) {
        print("presentArtistDetailsPage: \(artistId)")
        // TODO: present a Ticketmaster Artist/Attraction details page
    }

    /// Method is invoked if the core app need to display event detail page..
    /// - parameter eventId: Identidier of the event to be launched in EDP.
    func presentEventDetailsPage(with eventId: String) {
        print("presentEventDetailsPage: \(eventId)")
        // TODO: present a Ticketmaster Event details page
    }

    /// Method is invoked if the core app need to display venue detail page..
    /// - parameter venueId: Identidier of the venue to be launched inVADP.
    func presentVenueDetailsPage(with venueId: String) {
        print("presentVenueDetailsPage: \(venueId)")
        // TODO: present a Ticketmaster Venue details page
    }

    /// Called when the list of events changes
    func didUpdateOrderedEvents() {
        print("didUpdateOrderedEvents")
        // TODO: log to analytics
    }

    /// Called when the list of tickets change for a particular event ID
    /// - parameter eventId: Identifier of the event with ticket updates.
    func didUpdateTickets(eventId: String) {
        print("didUpdateTickets: \(eventId)")
        // TODO: log to analytics
    }

    /// Method is invoked if the client app needs to handle the bar button action
    ///
    /// - Parameters:
    ///   - page: events or tickets page
    ///   - buttonTitle: title of button pressed
    ///   - order: contextual order info (if any)
    func handleBarButtonAction(page: PSDK.PresencePage, buttonTitle: String, order: PresenceOrder?) {
        let event = order?.eventIdentifier ?? "?"
        let orders = order?.orderIdentifiers ?? []
        
        print("handleBarButtonAction: \(buttonTitle) pressed")
        print( "Event: \(event)")
        print(" Orders: \(orders)")

        // user has pressed the barButton Action on for a particular Event/Order
        // TODO: handle action here (for example: "Help" might link to your Customer Support page)
    }
}
