//
//  PresenceManager+VenueDelegate.swift
//  PresenceSDKDemoIntegration
//
//  Created by Jonathan Backer on 10/11/21.
//  Copyright © 2021 Ticketmaster. All rights reserved.
//

import Foundation
import PresenceSDK // for PresenceVenueDelegate

extension PresenceManager: PresenceVenueDelegate {
    
    // all methods are required (if delegate is implemented)
    
    /// Method is invoked upon opening an Event
    ///
    /// - Task: fetch and return Venue SDK Identifier
    ///
    /// - Parameters:
    ///   - identifier: venue identifier (from Ticketmaster)
    ///   - completion:
    ///    - sdkIdentifier: venue identifier (from venue concessions SDK)
    ///    - error: an error occured
    func venueConcessionsSdkIdentifier(forIdentifier identifier: String, completion: @escaping (_ sdkIdentifier: String?, _ error: Error?) -> Void) {
        print("User is viewing tickets for Ticketmaster venue: \(identifier)")
        
        // TODO: if your app integrates with venue concessions, return that SDK's venue `sdkIdentifier`
        /// for example, VenueNextSDK calls this `sdkIdentifier` an "instance"
        //completion("arsenal", nil) // this will show the Venue Concessions upsell module
        
        // TODO: if your app does not integrate with venue concessions, either don't implement this delegate or return `nil`
        completion(nil, nil) // do not show Venue Concessions upsell module
    }
    
    /// Method is invoked when the user presses a Venue Concessions button
    ///
    /// - Parameters:
    ///   - identifier: Identifier of the venue (from Ticketmaster)
    ///   - sdkIdentifier: Identifier of the venue (from venue concessions SDK)
    ///   - concessionsButtonPressed: User pressed `Orders` or `Wallet` button
    func venue(identifier: String, sdkIdentifier: String, concessionsButtonPressed: PSDK.VenueConcessionsButtonType) {
        
        // TODO: initialize Venue Concessions SDK for the given Venue `sdkIdentifier`
        //VenueNextWeb.shared.initialize("<ORGANIZATION_NAME>", instance: sdkIdentifier)

        switch concessionsButtonPressed {
        case .order:
            print("User has pressed the Order button on the Venue Concessions upsell module for: \(sdkIdentifier)")
            // TODO: present Venue Concessions SDK ordering
            //navigationController?.pushFnB() // VenueNextSDK
        case .wallet:
            print("User has pressed the Wallet button on the Venue Concessions upsell module for: \(sdkIdentifier)")
            // TODO: present Venue Concessions SDK wallet
            //navigationController?.pushWallet() // VenueNextSDK
        @unknown default:
            print("User has pressed an unknown button on the Venue Concessions upsell module for: \(sdkIdentifier)")
            // TODO: maybe a new button was added? present some reasonable default
            //navigationController?.pushFnB() // VenueNextSDK
        }
    }
}
