//
//  PresenceManager.swift
//  PresenceSDKDemoIntegration
//
//  Created by Jonathan Backer on 6/4/22.
//  Copyright © 2022 Ticketmaster. All rights reserved.
//

import Foundation
import UIKit
import PresenceSDK // for PSDK.shared

/// this class listens to PresenceSDK and implements the appropriate delegate protocols
class PresenceManager: NSObject {
    
    /// singleton
    static let shared = PresenceManager()
    
    override init() {
        super.init()
        
        // 1. optional, collect analytics about Presence SDK
        addSDKNotificationHandlers() // see PresenceVC+Notifications.swift

        // 2. optional, be informed about login state changes
        PSDK.shared.loginDelegate = self //see PresenceVC+LoginDelegate.swift
        
        // 3. optional, be informed about ticket/order changes, action button
        PSDK.shared.orderDelegate = self // see PresenceVC+OrderDelegate.swift
        PSDK.shared.setTicketsActionButtonText(title: "Help") // optional

        // 4. optional, venue concessions integration
        PSDK.shared.venueDelegate = self // see PresenceVC+VenueDelegate.swift
    }
}
